@@ -24,7 +24,7 @@ class Command(BaseCommand):
 
         call_command('reviewssummary')
 
-        call_command('progresssummary')
+        # call_command('progresssummary')
 
         call_command('notifiesme')
 
